enRich-package:
An R package for the analysis of multiple ChIP-seq data.
Description
enRich is an R package that performs a joint statistical modelling of ChIP-seq data, accounting for technical/biological replicates, multiple conditions and
the different IP efficiencies of individual experiments.
Details
|
Package: |
| enRich |
|
Type: |
| Package |
|
Version: |
| 3.0 |
|
Date: |
| 2015-10-19 |
|
Depends: |
| R(>= 3.2.2), parallel |
|
License: |
| GPL (>=2) |
|
LazyLoad: |
| yes |
mainfunctions: mix, mix.joint, mrf, mrf.joint, enrich.mix, enrich.mrf
References
Bao et al. Accounting for immunoprecipitation efficiencies in the statistical analysis of ChIP-seq data. BMC Bioinformatics 2013, 14:169 DOI:10.1186/1471-2105-14-169.
Bao et al. Joint modelling of ChIP-seq data via a Markov random field model, Biostatistics 2014, 15(2):296-310 DOI:10.1093/biostatistics/kxt047.